NullProvider class

The NullProvider class is a RepositoryProvider that does not provide any backend services. This provider is used when a feature does not require any backend services to function.

Inheritance

Constructors

NullProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
providerEventStream → Stream<ProviderEvent>
Streams events emitted by the provider to the consumers of the provider
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Disposes the repository provider. This method should close and release any resources used by the backend services.
override
initialize() → Future<void>
Initializes the repository provider. This method should setup persistent connections to the backend services and initialize any resources used by the backend services.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited