Message class

A message that can be displayed to the user to provide information or alert the user of an issue.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isError → bool
no setter
message → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → MessageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

alert(String message, [String? messageId]) → Message
error(String message, [String? messageId]) → Message
info(String message, [String? messageId]) → Message
warning(String message, [String? messageId]) → Message