FeatureServices class final

Container for feature services and BLoCs.

Constructors

FeatureServices()

Properties

hashCode → int
The hash code for this object.
no setterinherited
providers → List<BlocProvider<StateStreamableSource<Object?>>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<Service<State, RepositoryProvider>>
final

Methods

add<T extends Service<State, RepositoryProvider>>(FeatureBloCCreator<T> creator) → void
get<T extends Service<State, RepositoryProvider>>() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited